@@ -74,29 +74,12 @@ config_actor_socket.connect('ipc://configCommands')
 request_lock = gevent.lock.RLock()
 
 
-@app.before_first_request
-def initialize():
-    gevent.spawn(config_subscriber)
-    # wait until we have received the first config publish
-    first_cfg_received.wait()
-
-
-def send_config_request(request):
-    global config_actor_socket
-    request_lock.acquire()
-    try:
-        return send_zmq_request_socket(config_actor_socket, request)
-    finally:
-        request_lock.release()
-
-
 def config_subscriber():
     global config
     ctx = zmq.Context()
     subscriber_socket = ctx.socket(zmq.SUB)
     subscriber_socket.connect('ipc://configPublisher')
     subscriber_socket.setsockopt(zmq.SUBSCRIBE, Messages.CONFIG_FULL)
-    send_config_request(Messages.PUBLISH_CONFIG)
     while True:
         poller = zmq.Poller()
         poller.register(subscriber_socket, zmq.POLLIN)
@@ -109,6 +92,17 @@ def config_subscriber():
                 logger.debug('Config received')
 
 
+def send_config_request(request):
+    global config_actor_socket
+    request_lock.acquire()
+    try:
+        return send_zmq_request_socket(config_actor_socket, request)
+    finally:
+        request_lock.release()
+
+gevent.spawn(config_subscriber)
+gevent.spawn_later(1, send_config_request, Messages.PUBLISH_CONFIG)
+
 @login_manager.user_loader
 def user_loader(userid):
     userid = userid.encode('utf-8')
